@@ -13,14 +13,15 @@ from .collection import (
     LazyList,
     identity,
     prod,
+    Singleton,
 )
-from .compare import content_diff
+from .comparison import content_diff
 from .conversion import (
     basedict,
     dict2str,
     err2str,
 )
-from .files import (
+from .os import (
     mkdirs,
     rmdirs,
     sopen,
