@@ -1,9 +1,9 @@
 """Alternatives to Python's built-in containers"""
-
 from .deepdefaultdict import defaultdict, deepdefaultdict
 from .functions import (
     identity,
     prod,
 )
 from .lazylist import lazy_content, LazyList
-from .spestr import SpeStr
+from .flatstr import FlatStr
+from .singleton import Singleton
