@@ -1,10 +1,10 @@
-"""Provide functions to convert different structures / objects"""
+"""Functions to convert different structures / objects"""
 
 from .dictionary import basedict, dict2str
 from .error import err2str
 from .temporality import (
-    convert_ts,
-    dt2float,
-    float2dt,
+    secs2unit,
+    dt2ts,
+    ts2dt,
     str2dt,
 )
